@@ -2,6 +2,7 @@ import json
 import warnings
 from glob import iglob
 from typing import List, Any, Callable
+from dh_client.exceptions import FailedToEmmitMpc
 
 import requests
 from datahub.emitter.mcp import MetadataChangeProposalWrapper, DictWrapper
@@ -43,9 +44,12 @@ class Entity:
                 )
                 r.raise_for_status()
             else:
-                self.emmiter.emit(
-                    MetadataChangeProposalWrapper(changeType=change_type, **mpc_)
-                )
+                try:
+                    self.emmiter.emit(
+                        MetadataChangeProposalWrapper(changeType=change_type, **mpc_)
+                    )
+                except Exception as e:
+                    raise FailedToEmmitMpc(mpc_, change_type) from e
 
     def _create_mpc_from_file(
         self, file_pattern: str, filter_func: Callable = None, recursive: bool = False
