@@ -4,6 +4,10 @@ import datahub.emitter.mce_builder as builder
 import datahub.metadata.schema_classes as models
 
 from dh_client.entities import Entity
+from dh_client.entities.glossary_terms import GlossaryTerm
+from dh_client.entities.links import Link
+from dh_client.entities.owners import Owner
+from dh_client.entities.tags import Tag
 
 
 class Dashboard(Entity):
@@ -14,7 +18,8 @@ class Dashboard(Entity):
 
     entity_type: str = "dashboard"
 
-    def _get_chart_urn(self, name: str, platform: str) -> str:
+    @staticmethod
+    def _get_chart_urn(name: str, platform: str) -> str:
         """Get the chart URN.
 
         Args:
@@ -26,7 +31,16 @@ class Dashboard(Entity):
         """
         return builder.make_chart_urn(platform=platform, name=name)
 
-    def _get_dashboard_urn(self, name: str, platform: str) -> str:
+    @staticmethod
+    def _get_dashboard_urn(name: str, platform: str) -> str:
+        """Get the dashboard URN.
+
+        Args:
+             name: The dashboard name.
+             platform: The dashboard platform.
+
+        Return: The dashboard URN.
+        """
         return builder.make_dashboard_urn(platform=platform, name=name)
 
     def _create_mpc(
@@ -39,7 +53,7 @@ class Dashboard(Entity):
         owners: List[str] = None,
         glossary_terms: List[str] = None,
         url: str = None,
-        links: List[str] = None,
+        links: dict[str, str] = None,
         platform: str = "datastudio",
     ) -> List[dict]:
         """Create a dashboard mpc.
@@ -60,6 +74,7 @@ class Dashboard(Entity):
         Returns: A list with a single mpc dictionary.
         """
         inputs = inputs or []
+        dashboard_urn = self._get_dashboard_urn(name, platform)
 
         mpc = [
             self._create_mpc_dict(
@@ -86,8 +101,8 @@ class Dashboard(Entity):
                 ),
             ),
             self._create_mpc_dict(
-                "dashboard",
-                self._get_dashboard_urn(name, platform),
+                self.entity_type,
+                dashboard_urn,
                 "dashboardInfo",
                 models.DashboardInfoClass(
                     title=title if title else name,
@@ -104,5 +119,28 @@ class Dashboard(Entity):
         ]
 
         if tags:
-            mpc.append({"entityType": ""})
+            mpc.append(
+                Tag.create_mpc_association(self.entity_type, dashboard_urn, tags)
+            )
+        if owners:
+            mpc.append(
+                Owner.create_mpc_association(self.entity_type, dashboard_urn, owners)
+            )
+        if glossary_terms:
+            mpc.append(
+                GlossaryTerm.create_mpc_association(
+                    self.entity_type,
+                    dashboard_urn,
+                    glossary_terms,
+                    self.emmiter.datahub_actor,
+                )
+            )
+
+        if links:
+            mpc.append(
+                Link.create_mpc_association(
+                    self.entity_type, dashboard_urn, links, self.emmiter.datahub_actor
+                )
+            )
+
         return mpc
